@@ -5,5 +5,5 @@ pub enum WorkOSError {
     #[error("identifier `{0}` not found")]
     NotFound(String),
     #[error("unknown error")]
-    Unknown,
+    Unknown(#[from] anyhow::Error),
 }
